---
title: Spree 3.5.0
section: release_notes
order: 5
---

## Major/New Features

3.5 is a smaller release to lay the groundwork for major new features
described in [Spree Development Roadmap](https://github.com/spree/spree/milestones?direction=asc&sort=due_date&state=open).
It also contains number of bug fixes and improvements besides described in this document.

### Multi-store management

We've added an ability to manage multiple stores in one Spree instance of your application.
Thanks to that you can easily create stores per region / language / currency.
This feature will be enhanced in the next releases.

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/8545)

### Extracted Analytics tracker into an Extension

Our goal is always to keep the core Spree lean and flexible that's why we've moved all of the code of
Analytics Trackers to an Extension which you can use with any `Spree 3.1+` version.

[Spree Analytics Trackers](https://github.com/spree-contrib/spree_analytics_trackers) extension currently supports Google Analytics and Segment.com.

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/8408)

### Admin Panel views exporter

You can easily copy all of the default spree admin Panel into
your project with just one command line:

```bash
rails g spree:backend:copy_views
```

We hope will make backend customization the Admin Panel a lot easier.

Contributed by [supatk](https://github.com/spree/spree/issues/8583)

## Installation

### Add Spree gems to Gemfile

```ruby
gem 'spree', '~> 3.5.0'
gem 'spree_auth_devise', '~> 3.3'
gem 'spree_gateway', '~> 3.3'
```

### Run `bundle install`

### Use the install generators to set up Spree

```shell
rails g spree:install --user_class=Spree::User
rails g spree:auth:install
rails g spree_gateway:install
```

## Upgrade

### Update Gemfile

```ruby
gem 'spree', '~> 3.5.0'
```

### Run `bundle update`

### Install missing migrations

```bash
rails spree:install:migrations
rails spree_auth:install:migrations
rails spree_gateway:install:migrations
```

### Run migrations

```bash
rails db:migrate
```

### Other Gotchas

#### Install Spree Analytics Trackers extension

If you were previously using Analytics Trackers feature you need to install it as an extension
as it was [extracted from the core](https://github.com/spree/spree/pull/8408).

1. Add [Spree Analytics Trackers](https://github.com/spree-contrib/spree_analytics_trackers) to your `Gemfile`:

```ruby
gem 'spree_analytics_trackers', github: 'spree-contrib/spree_analytics_trackers'
```

2. Install the gem using Bundler:

```bash
bundle install
```

3. Copy and run migrations:

```bash
bundle exec rails g spree_analytics_trackers:install
```

You're good to go!

## Noteworthy Changes

Also please review each of the noteworthy changes, and ensure your customizations
or extensions are not effected. If you are affected by a change, and have any
of your own tips please submit a PR to help the next person!

- Added `Address#EXCLUDED_KEYS_FOR_COMPARISION` so developers won't need to rewrite `Address#same_as` method

  [Spark Solutions](https://github.com/spree/spree/pull/8387)

- Added `PromotionActionLineItem` validations

  [Spark Solutions](https://github.com/spree/spree/pull/8533)

- Renamed `FrontendHelper#breadcrumbs` to `FrontendHelper#spree_breadcrumbs` and
  `Admin::NavigationHelper#icon` to `Admin::NavigationHelper#spree_icon`

  [Spark Solutions](https://github.com/spree/spree/pull/8445)

- Deprecated `EnvironmentExtension`

  [Spark Solutions](https://github.com/spree/spree/pull/8459)

- Deprecated `render_404`

  [Spark Solutions](https://github.com/spree/spree/pull/8465)

- Updated javascript libraries in vendor

  [Spark Solutions](https://github.com/spree/spree/pull/8402)

- Added `Dockerfile` for sandbox application

  [Spark Solutions](https://github.com/spree/spree/pull/8402)

- Replaced phantomjs with chrome headless

  [Spark Solutions](https://github.com/spree/spree/pull/8429)

- Replaced FactoryGirl with FactoryBot

  [Spark Solutions](https://github.com/spree/spree/pull/8431)

- Moved EmailValidator from lib to app

  [Spark Solutions](https://github.com/spree/spree/pull/8612)

- Added `rubocop-rspec` and fixed linter issues

  [artplan1](https://github.com/spree/spree/pull/8574)

- Added searching for a taxon with taxonomy in api

  [saravanak](https://github.com/spree/spree/pull/8594)

- `rescue nil` removed from promotion rules and and promotion actions partials

  [leemour](https://github.com/spree/spree/pull/8510)

- Dropped dependency on `with_model` gem

  [Spark Solutions](https://github.com/spree/spree/pull/8528)

- Updated `paperclip` to `~> 6.0.0`

  [Spark Solutions](https://github.com/spree/spree/pull/8775)

## Full Changelog

You can view the full changes using [Github Compare](https://github.com/spree/spree/compare/3-4-stable...3-5-stable).
